/*
 The Bluetooth Library for client-server communication
 Copyright (C) 2006 Martin Vysny

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 */
package net.sf.btw.btlib;

import java.util.Vector;

/**
 * Listens for lookup events. Events are fired by {@link ServerLookup}.
 * @author Martin Vysny
 */
public interface ILookupListener {
	/**
	 * Informs the client that a server has been found.
	 * 
	 * @param server
	 *            information about the server.
	 */
	void serverFound(final ServerInfo server);

	/**
	 * Invoked when the server scan finishes.
	 * 
	 * @param servers
	 *            list of {@link ServerInfo}.
	 * @param completely
	 *            if <code>true</code> then the scan finished succesfully. If
	 *            <code>false</code> then the scan was interrupted or some
	 *            unrecoverable error occured.
	 */
	void serverScanFinished(final Vector servers, final boolean completely);

	/**
	 * Error scanning servers.
	 * 
	 * @param ex
	 *            exception.
	 */
	void serverScanError(final Exception ex);
}
